OC.L10N.register(
    "tasks",
    {
    "Tasks" : "Úkoly",
    "Due yesterday" : "Termín byl včera",
    "Due today" : "Termín je dnes",
    "Due tomorrow" : "Termín zítra",
    "Due on" : "Platnost skončí",
    "Started yesterday" : "Začalo včera",
    "Starts today" : "Začíná dnes",
    "Starts tomorrow" : "Začne zítra",
    "Started on" : "Začalo",
    "Starts on" : "Začíná",
    "[Remind me yesterday at ]HH:mm" : "[Připomeň mi včera v ]HH:mm",
    "[Remind me today at ]HH:mm" : "[Připomenout mi dnes v ]HH:mm",
    "[Remind me tomorrow at ]HH:mm" : "[Připomenout mi zítra v ]HH:mm",
    "[Remind me on ]MMM DD, YYYY,[ at ]HH:mm" : "[Připomeň mi v ]MMM DD, YYYY,[ v ]HH:mm",
    "Yesterday" : "Včera",
    "Today" : "Dnes",
    "Tomorrow" : "Zítra",
    "in %s" : "v %s",
    "%s ago" : "před %s",
    "seconds" : "sekund",
    "a minute" : "minuta",
    "%d minutes" : "%d minut",
    "an hour" : "hodina",
    "%d hours" : "%d hodin",
    "a day" : "den",
    "%d days" : "%d dní",
    "a month" : "měsíc",
    "%d months" : "%d měsíců",
    "a year" : "rok",
    "%d years" : "%d roky",
    "week" : "týden",
    "weeks" : "týdny",
    "day" : "den",
    "days" : "dnech",
    "hour" : "hodina",
    "hours" : "hodiny",
    "minute" : "minuta",
    "minutes" : "minuty",
    "second" : "sekunda",
    "before beginning" : "před začátkem",
    "after beginning" : "po začátku",
    "before end" : "před koncem",
    "after end" : "po konci",
    "Comment" : "Komentář",
    "Add a comment" : "Přidat komentář",
    "This will delete the Calendar \"%s\" and all of its entries." : "Tímto dojde ke smazání kalendáře \"%s\" a všech jeho záznamů.",
    "The name \"%s\" is already used." : "Název \"%s\" je již používán.",
    "An empty name is not allowed." : "Prázdný název není povolen.",
    "Hidden" : "Skrytý",
    "Visible" : "Viditelný",
    "Automatic" : "Automatický",
    "Sunday" : "Neděle",
    "Monday" : "Pondělí",
    "Tuesday" : "Úterý",
    "Wednesday" : "Středa",
    "Thursday" : "Čtvrtek",
    "Friday" : "Pátek",
    "Saturday" : "Sobota",
    "Add an important item in \"%s\"..." : "Přidat důležitou položku do \"%s\"...",
    "Add an item due today in \"%s\"..." : "Přidat položku s vypršením ke dnešku do \"%s\"...",
    "Add an item in \"%s\"..." : "Přidat položku do \"%s\"...",
    "Add a current item in \"%s\"..." : "Přidat současnou položku do \"%s\"...",
    "Add a subtask to \"%s\"..." : "Přidat podúkol k \"%s\"...",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n dokončený úkol","%n dokončené úkoly","%n dokončených úkolů","%n dokončených úkolů"],
    "Hours" : "Hodiny",
    "Minutes" : "Minuty",
    "Set due date" : "Nastavit datum vypršení",
    "%s %% completed" : "%s %% dokončeno",
    "priority %s: " : "priorita %s: ",
    "high" : "vysoká",
    "medium" : "střední",
    "low" : "nízká",
    "no priority assigned" : "priorita nebyla přiřazena",
    "Remind me" : "Připomenout",
    "at the end" : "na konci",
    "at the beginning" : "na začátku",
    "Set start date" : "Nastavit počáteční datum",
    "{calendar} shared by {owner}" : "{calendar} sdílen uživatelem {owner}",
    "Unnamed" : "Nepojmenovaný",
    "Important" : "Důležité",
    "Week" : "Týden",
    "All" : "Vše",
    "Current" : "Aktuální",
    "Completed" : "Dokončeno",
    "Delete" : "Smazat",
    "Cancel" : "Zrušit",
    "Edit" : "Upravit",
    "Link" : "Odkaz",
    "Download" : "Stáhnout",
    "Save" : "Uložit",
    "Add List..." : "Přidat seznam...",
    "New List" : "Nový seznam",
    "Settings" : "Nastavení",
    "Start of week" : "Začátek týdne",
    "Visibility of Smart Collections" : "Viditelnost Chytrých kolekcí",
    "Change sort order" : "Změnit řazení",
    "Default" : "Výchozí",
    "Due date" : "Datum ukončení",
    "Start date" : "Datum počátku",
    "Priority" : "Priorita",
    "Alphabetically" : "Abecedně",
    "Manually" : "Manuálně",
    "Load remaining completed tasks." : "Načíst zbývající dokončené úkoly.",
    "Task is completed" : "Úkol je dokončen",
    "All day" : "Celý den",
    "(New category)" : "(Nová kategorie)",
    "Select categories..." : "Vybrat kategorie...",
    "Loading the task..." : "Nahrávám úkol...",
    "Task not found!" : "Úkol nenalezen!",
    "add a subtask to" : "přidat podúkol k",
    "Toggle subtasks" : "Přepnout podúkoly",
    "Toggle completed subtasks" : "Přepnout dokončené podúkoly"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
